summaryrefslogtreecommitdiff
path: root/plugins/test.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/test.c')
-rw-r--r--plugins/test.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/test.c b/plugins/test.c
index 9df8a61a..803a7aa9 100644
--- a/plugins/test.c
+++ b/plugins/test.c
@@ -39,13 +39,13 @@ test_plugin_class_init (TestPluginClass *klass)
static void
initialize (SalutPlugin *plugin,
TpBaseConnectionManager *connection_manager,
- SalutCreateProtocolImpl callback)
+ const SalutPluginInitializeCallbacks *callbacks)
{
DEBUG ("%p on connection manager %p", plugin, connection_manager);
/* If you wanted to add another protocol you could do it here by
* creating the protocol object and then calling
* tp_base_connection_manager_add_protocol(). */
}
static GPtrArray *
@@ -39,13 +39,13 @@ test_plugin_class_init (TestPluginClass *klass)
DEBUG ("%p on connection manager %p", plugin, connection_manager);
/* If you wanted to add another protocol you could do it here by
- * creating the protocol object and then calling
- * tp_base_connection_manager_add_protocol(). */
+ * creating the protocol object with callbacks->create_protocol
+ * and then calling tp_base_connection_manager_add_protocol(). */
}
static GPtrArray *